aboutsummaryrefslogtreecommitdiff
path: root/build.gradle
diff options
context:
space:
mode:
authorMartin Robertz <dream-master@gmx.net>2022-12-22 21:01:54 +0100
committerMartin Robertz <dream-master@gmx.net>2022-12-22 21:01:54 +0100
commit13685048345804be831cad8bdf789d673aa89e7e (patch)
tree21e4fbe09837961b681a9be2f3137d868ab18731 /build.gradle
parentc696f2f0825fc30b3da3be002e997d9ab607debb (diff)
downloadGT5-Unofficial-13685048345804be831cad8bdf789d673aa89e7e.tar.gz
GT5-Unofficial-13685048345804be831cad8bdf789d673aa89e7e.tar.bz2
GT5-Unofficial-13685048345804be831cad8bdf789d673aa89e7e.zip
update BS
Diffstat (limited to 'build.gradle')
-rw-r--r--build.gradle25
1 files changed, 19 insertions, 6 deletions
diff --git a/build.gradle b/build.gradle
index 1930cd1be0..9ceb5abe8c 100644
--- a/build.gradle
+++ b/build.gradle
@@ -1,4 +1,4 @@
-//version: 1669411416
+//version: 1671313514
/*
DO NOT CHANGE THIS FILE!
Also, you may replace this file at any time if there is an update available.
@@ -31,7 +31,7 @@ buildscript {
url 'https://maven.minecraftforge.net'
}
maven {
// GTNH ForgeGradle Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
@@ -45,6 +45,8 @@ buildscript {
}
}
dependencies {
+ //Overwrite the current ASM version to fix shading newer than java 8 applicatations.
+ classpath 'org.ow2.asm:asm-debug-all-custom:5.0.3'
classpath 'net.minecraftforge.gradle:ForgeGradle:1.2.13'
}
}
@@ -278,7 +280,9 @@ minecraft {
runDir = 'run'
if (replaceGradleTokenInFile) {
- replaceIn replaceGradleTokenInFile
+ for (f in replaceGradleTokenInFile.split(',')) {
+ replaceIn f
+ }
if (gradleTokenModId) {
replace gradleTokenModId, modId
}
@@ -330,6 +334,12 @@ repositories {
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
+ if (usesMixinDebug.toBoolean()) {
+ maven {
+ name = "Fabric Maven"
+ url = "https://maven.fabricmc.net/"
+ }
+ }
}
}
@@ -338,10 +348,13 @@ dependencies {
annotationProcessor('org.ow2.asm:asm-debug-all:5.0.3')
annotationProcessor('com.google.guava:guava:24.1.1-jre')
annotationProcessor('com.google.code.gson:gson:2.8.6')
- annotationProcessor('com.gtnewhorizon:gtnhmixins:2.1.1:processor')
+ annotationProcessor('com.gtnewhorizon:gtnhmixins:2.1.3:processor')
+ if (usesMixinDebug.toBoolean()) {
+ runtimeOnly('org.jetbrains:intellij-fernflower:1.2.1.16')
+ }
}
if (usesMixins.toBoolean() || forceEnableMixins.toBoolean()) {
- compile('com.gtnewhorizon:gtnhmixins:2.1.1')
+ compile('com.gtnewhorizon:gtnhmixins:2.1.3')
}
}
@@ -694,7 +707,7 @@ if (modrinthProjectId.size() != 0 && System.getenv("MODRINTH_TOKEN") != null) {
}
}
if (usesMixins.toBoolean()) {
- addModrinthDep("required", "version", "gtnhmixins")
+ addModrinthDep("required", "project", "gtnhmixins")
}
tasks.modrinth.dependsOn(build)
tasks.publish.dependsOn(tasks.modrinth)
@@ -31,7 +31,7 @@ buildscript {
}
maven {
- // GTNH ForgeGradle Fork
+ // GTNH ForgeGradle and ASM Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"